@@ -64,7 +64,10 @@ get_from_stream(), get_from_vm(), get_xdg_icon_from_vm(), get_through_dvm()'''
         p = subprocess.Popen(['convert',
             '-depth', '8',
             '-size', '{0[0]}x{0[1]}'.format(self._size),
-            'rgba:-', dst], stdin=subprocess.PIPE)
+            'rgba:-',
+            '+set', 'date:create',
+            '+set', 'date:modify',
+            dst], stdin=subprocess.PIPE)
         p.stdin.write(self._rgba)
         p.stdin.close()
 
@@ -256,7 +259,7 @@ get_from_stream(), get_from_vm(), get_xdg_icon_from_vm(), get_through_dvm()'''
         del untrusted_width, untrusted_height
 
         expected_data_len = width * height * 4    # RGBA
-        untrusted_data = await reader.read(expected_data_len)
+        untrusted_data = await reader.readexactly(expected_data_len)
         if len(untrusted_data) != expected_data_len:
             raise ValueError( \
                 'Image data length violation (is {0}, should be {1})'.format( \
